==> mltrain-0.2.0.tar.gz: mltrain-0.2.0/README.md <==
#   m l t r a i n 
 
 
 
 * * m l t r a i n * *   i s   a   c o m p r e h e n s i v e   m a c h i n e   l e a r n i n g   p a c k a g e   t h a t   p r o v i d e s   e a s y - t o - u s e   i m p l e m e n t a t i o n s   o f   p o p u l a r   a l g o r i t h m s .   T h i s   t o o l k i t   i s   d e s i g n e d   t o   h e l p   d e v e l o p e r s   a n d   r e s e a r c h e r s   q u i c k l y   p r o t o t y p e   a n d   d e p l o y   m a c h i n e   l e a r n i n g   m o d e l s .   T h e   p a c k a g e   i n c l u d e s   v a r i o u s   s u p e r v i s e d   a n d   u n s u p e r v i s e d   l e a r n i n g   a l g o r i t h m s ,   e a c h   b u i l t   f r o m   s c r a t c h   f o r   m a x i m u m   f l e x i b i l i t y   a n d   u n d e r s t a n d i n g . 
 
 
 
 # #   F e a t u r e s 
 
 
 
 -   * * L i n e a r   R e g r e s s i o n : * *   I m p l e m e n t a t i o n   o f   l i n e a r   r e g r e s s i o n   u s i n g   g r a d i e n t   d e s c e n t . 
 
 -   * * L o g i s t i c   R e g r e s s i o n : * *   I n c l u d e s   l o g i s t i c   r e g r e s s i o n   w i t h   b i n a r y   c l a s s i f i c a t i o n   o n l y . 
 
 -   * * D e c i s i o n   T r e e : * *   A   f l e x i b l e   d e c i s i o n   t r e e   i m p l e m e n t a t i o n   f o r   C l a s s i f i c a t i o n   o n l y . 
 
 -   * * R a n d o m   F o r e s t : * *   A n   e n s e m b l e   m e t h o d   u s i n g   m u l t i p l e   d e c i s i o n   t r e e s   f o r   i m p r o v e d   a c c u r a c y . 
 
 -   * * S u p p o r t   V e c t o r   M a c h i n e   ( S V M ) : * *   I n c l u d e s   b o t h   l i n e a r   a n d   k e r n e l - b a s e d   S V M s   w i t h   s u p p o r t   f o r   s o f t   m a r g i n s . 
 
 -   * * k - N e a r e s t   N e i g h b o r s   ( k - N N ) : * *   A   s i m p l e   a n d   i n t u i t i v e   c l a s s i f i c a t i o n   a l g o r i t h m . 
 
 -   * * N a i v e   B a y e s : * *   S u p p o r t s   f o r   G a u s s i a n   N a i v e   B a y e s   f o r   c o n t i n u o u s   D a t a . 
 
 -   * * K M e a n s   C l u s t e r i n g : * *   A   c l u s t e r i n g   a l g o r i t h m . 
 
 -   * * D B S C A N : * *   A   d e n s i t y - b a s e d   c l u s t e r i n g   a l g o r i t h m   f o r   d i s c o v e r i n g   c l u s t e r s   o f   a r b i t r a r y   s h a p e . 
 
 
 
 # #   I n s t a l l a t i o n 
 
 
 
 Y o u   c a n   i n s t a l l   t h e   p a c k a g e   u s i n g   ` p i p ` : 
 
 
 
 ` ` ` b a s h 
 
 p i p   i n s t a l l   m l t r a i n 
 
 ` ` ` 
 
 
 
 # #   U s a g e 
 
 # #   S u p e r v i s e d   L e a r n i n g   M o d e l s 
 
 # # #   L i n e a r   R e g r e s s i o n 
 
 I t   i s   B u i l t   f r o m   s c r a t c h .   I t   c a n   b e   a p p l i e d   t o   M u l t i p l e   W e i g h t s . . . 
 
 ` ` ` p y t h o n 
 
 f r o m   m l t r a i n . s u p e r v i s e d . L i n e a r R e g r e s s i o n   i m p o r t   L i n e a r R e g r e s s i o n 
 
 
 
 #   I n i t i a l i z e   t h e   m o d e l 
 
 m o d e l   =   L i n e a r R e g r e s s i o n ( l e a r n i n g _ r a t e = 0 . 0 1 ,   e p o c h s = 1 0 0 0 ) 
 
 
 
 #   T r a i n   t h e   m o d e l 
 
 m o d e l . t r a i n ( X _ t r a i n ,   y _ t r a i n ) 
 
 
 
 #   M a k e   p r e d i c t i o n s 
 
 p r e d i c t i o n s   =   m o d e l . p r e d i c t ( X _ t e s t ) 
 
 
 
 ` ` ` 
 
 # # #   L o g i s t i c   R e g r e s s i o n 
 
 I m p l e m e n t e d   o n l y   B i n a r y   C l a s s i f i c a t i o n . 
 
 ` ` ` p y t h o n 
 
 f r o m   m l t r a i n . s u p e r v i s e d . L o g i s t i c R e g r e s s i o n   i m p o r t   L o g i s t i c R e g r e s s i o n 
 
 
 
 #   I n i t i a l i z e   t h e   m o d e l 
 
 m o d e l   =   L o g i s t i c R e g r e s s i o n ( l e a r n i n g _ r a t e = 0 . 0 1 ,   e p o c h s = 1 0 0 0 ) 
 
 
 
 #   T r a i n   t h e   m o d e l 
 
 m o d e l . t r a i n ( X _ t r a i n ,   y _ t r a i n ) 
 
 
 
 #   M a k e   p r e d i c t i o n s 
 
 p r e d i c t i o n s   =   m o d e l . p r e d i c t ( X _ t e s t ) 
 
 
 
 ` ` ` 
 
 # # #   K N N   M o d e l 
 
 Y o u   c a n   u s e   f o r   b o t h   R e g r e s s i o n   a n d   C l a s s i f i c a t i o n .   D e f a u l t   i s   g i v e n   b e l o w : - 
 
 ` ` ` p y t h o n 
 
 f r o m   m l t r a i n . s u p e r v i s e d . K N N   i m p o r t   K N N 
 
 
 
 #   I n i t i a l i z e   t h e   m o d e l 
 
 m o d e l   =   K N N ( k = 3 , d i s t a n c e = ' e u c l i d e a n ' , p u r p o s e = ' c l a s s i f i c a t i o n ' ) 
 
 
 
 #   T r a i n   t h e   m o d e l 
 
 m o d e l . t r a i n ( X _ t r a i n ,   y _ t r a i n ) 
 
 
 
 #   M a k e   p r e d i c t i o n s 
 
 p r e d i c t i o n s   =   m o d e l . p r e d i c t ( X _ t e s t ) 
 
 
 
 ` ` ` 
 
 
 
 # # #   N a i v e   B a y e s   M o d e l 
 
 I m p l e m e n t e d   o n l y   G a u s s i a n   N a i v e   B a y e s . 
 
 ` ` ` p y t h o n 
 
 f r o m   m l t r a i n . s u p e r v i s e d . N a i v e B a y e s   i m p o r t   N a i v e B a y e s 
 
 
 
 #   I n i t i a l i z e   t h e   m o d e l 
 
 m o d e l   =   N a i v e B a y e s ( ) 
 
 
 
 #   T r a i n   t h e   m o d e l 
 
 m o d e l . t r a i n ( X _ t r a i n ,   y _ t r a i n ) 
 
 
 
 #   M a k e   p r e d i c t i o n s 
 
 p r e d i c t i o n s   =   m o d e l . p r e d i c t ( X _ t e s t ) 
 
 
 
 ` ` ` 
 
 
 
 # # #   N a i v e   B a y e s   M o d e l 
 
 I m p l e m e n t e d   o n l y   G a u s s i a n   N a i v e   B a y e s . 
 
 ` ` ` p y t h o n 
 
 f r o m   m l t r a i n . s u p e r v i s e d . N a i v e B a y e s   i m p o r t   N a i v e B a y e s 
 
 
 
 #   I n i t i a l i z e   t h e   m o d e l 
 
 m o d e l   =   N a i v e B a y e s ( ) 
 
 
 
 #   T r a i n   t h e   m o d e l 
 
 m o d e l . t r a i n ( X _ t r a i n ,   y _ t r a i n ) 
 
 
 
 #   M a k e   p r e d i c t i o n s 
 
 p r e d i c t i o n s   =   m o d e l . p r e d i c t ( X _ t e s t ) 
 
 
 
 ` ` ` 
 
 # # #   D e c i s i o n   T r e e 
 
 I m p l e m e n t e d   o n l y   f o r   C l a s s i f i c a t i o n   P u r p o s e   o n l y .   D e f a u l t   P a r a m s   a r e   s h o w n   b e l o w : -   
 
 ` ` ` p y t h o n 
 
 f r o m   m l t r a i n . s u p e r v i s e d . D e c i s i o n T r e e   i m p o r t   D e c i s i o n T r e e 
 
 
 
 #   I n i t i a l i z e   t h e   m o d e l 
 
 m o d e l   =   D e c i s i o n T r e e ( m a x _ d e p t h = 1 0 ,   m i n _ s a m p l e s _ s p l i t = 2 ,   c r i t e r i a = ' g i n i ' ) 
 
 
 
 #   T r a i n   t h e   m o d e l 
 
 m o d e l . t r a i n ( X _ t r a i n ,   y _ t r a i n ) 
 
 
 
 #   M a k e   p r e d i c t i o n s 
 
 p r e d i c t i o n s   =   m o d e l . p r e d i c t ( X _ t e s t ) 
 
 
 
 ` ` ` 
 
 # # #   R a n d o m   F o r e s t 
 
 I m p l e m e n t e d   o n l y   f o r   C l a s s i f i c a t i o n   P u r p o s e   o n l y .   D e f a u l t   P a r a m s   a r e   s h o w n   b e l o w : -   
 
 ` ` ` p y t h o n 
 
 f r o m   m l t r a i n . s u p e r v i s e d . R a n d o m F o r e s t   i m p o r t   R a n d o m F o r e s t 
 
 
 
 #   I n i t i a l i z e   t h e   m o d e l 
 
 m o d e l   =   R a n d o m F o r e s t ( n _ t r e e s = 1 0 0 ,   m a x _ d e p t h = 1 0 ,   m i n _ s a m p l e s _ s p l i t = 2 ,   c r i t e r i a = ' g i n i ' ) 
 
 
 
 #   T r a i n   t h e   m o d e l 
 
 m o d e l . t r a i n ( X _ t r a i n ,   y _ t r a i n ) 
 
 
 
 #   M a k e   p r e d i c t i o n s 
 
 p r e d i c t i o n s   =   m o d e l . p r e d i c t ( X _ t e s t ) 
 
 
 
 ` ` ` 
 
 # # #   K e r n e l S V M   M o d e l 
 
 I m p l e m e n t e d   o n l y   f o r   C l a s s i f i c a t i o n   P u r p o s e   o n l y .   D e f a u l t   P a r a m s   a r e   s h o w n   b e l o w : -   
 
 ` ` ` p y t h o n 
 
 f r o m   m l t r a i n . s u p e r v i s e d . K e r n e l S V M   i m p o r t   K e r n e l S V M 
 
 
 
 #   I n i t i a l i z e   t h e   m o d e l 
 
 m o d e l   =   K e r n e l S V M ( C = 1 . 0 ,   k e r n e l _ t y p e = ' r b f ' ,   e p o c h s = 1 0 0 0 ,   l e a r n i n g _ r a t e = 0 . 0 1 ,   g a m m a = 0 . 5 ,   c o e f 0 = 0 ,   d e g r e e = 3 ) 
 
 
 
 #   T r a i n   t h e   m o d e l 
 
 m o d e l . t r a i n ( X _ t r a i n ,   y _ t r a i n ) 
 
 
 
 #   M a k e   p r e d i c t i o n s 
 
 p r e d i c t i o n s   =   m o d e l . p r e d i c t ( X _ t e s t ) 
 
 
 
 ` ` ` 
 
 # #   U n s u p e r v i s e d   L e a r n i n g   M o d e l s 
 
 # # #   K - M e a n s   C l u s t e r i n g   M o d e l 
 
 ` ` ` p y t h o n 
 
 f r o m   m l t r a i n . s u p e r v i s e d . K M e a n s   i m p o r t   K M e a n s 
 
 
 
 #   I n i t i a l i z e   t h e   m o d e l 
 
 m o d e l   =   K M e a n s ( k = 3 ,   e p o c h s = 1 0 0 ) 
 
 
 
 #   T r a i n   t h e   m o d e l   w h i c h   R e t u r n s   C l u s t e r   L a b e l s 
 
 c l u s t e r _ l a b e l s   =   m o d e l . t r a i n ( X _ t r a i n ,   y _ t r a i n ) 
 
 p r i n t ( c l u s t e r _ l a b e l s ) 
 
 
 
 ` ` ` 
 
 # # #   D B S C A N   C l u s t e r i n g   M o d e l 
 
 ` ` ` p y t h o n 
 
 f r o m   m l t r a i n . s u p e r v i s e d . D B S C A N   i m p o r t   D B S C A N 
 
 
 
 #   I n i t i a l i z e   t h e   m o d e l 
 
 m o d e l   =   D B S C A N ( e p s i l o n = 0 . 5 ,   m i n _ p o i n t s = 5 ) 
 
 
 
 #   T r a i n   t h e   m o d e l   w h i c h   R e t u r n s   C l u s t e r   L a b e l s 
 
 c l u s t e r _ l a b e l s   =   m o d e l . t r a i n ( X _ t r a i n ,   y _ t r a i n ) 
 
 p r i n t ( c l u s t e r _ l a b e l s ) 
 
 
 
 ` ` ` 
 
 # #   C o n t r i b u t i n g 
 
 
 
 P u l l   r e q u e s t s   a r e   w e l c o m e .   F o r   m a j o r   c h a n g e s ,   p l e a s e   o p e n   a n   i s s u e   f i r s t 
 
 t o   d i s c u s s   w h a t   y o u   w o u l d   l i k e   t o   c h a n g e . 
 
 
 
 P l e a s e   m a k e   s u r e   t o   u p d a t e   t e s t s   a s   a p p r o p r i a t e . 
 
 
 
 # #   L i c e n s e 
 
 
 
 [ M I T   L i c e n s e ] ( L I C E N S E ) 
 
 
 
 
 
 

==> mltrain-0.4.1.tar.gz: mltrain-0.4.1/README.md <==
#   m l t r a i n 
 
 
 
 * * m l t r a i n * *   i s   a   c o m p r e h e n s i v e   m a c h i n e   l e a r n i n g   p a c k a g e   t h a t   p r o v i d e s   e a s y - t o - u s e   i m p l e m e n t a t i o n s   o f   p o p u l a r   a l g o r i t h m s .   T h i s   t o o l k i t   i s   d e s i g n e d   t o   h e l p   d e v e l o p e r s   a n d   r e s e a r c h e r s   q u i c k l y   p r o t o t y p e   a n d   d e p l o y   m a c h i n e   l e a r n i n g   m o d e l s .   T h e   p a c k a g e   i n c l u d e s   v a r i o u s   s u p e r v i s e d   a n d   u n s u p e r v i s e d   l e a r n i n g   a l g o r i t h m s ,   e a c h   b u i l t   f r o m   s c r a t c h   f o r   m a x i m u m   f l e x i b i l i t y   a n d   u n d e r s t a n d i n g . 
 
 
 
 # #   F e a t u r e s 
 
 
 
 -   * * L i n e a r   R e g r e s s i o n : * *   I m p l e m e n t a t i o n   o f   l i n e a r   r e g r e s s i o n   u s i n g   g r a d i e n t   d e s c e n t . 
 
 -   * * L o g i s t i c   R e g r e s s i o n : * *   I n c l u d e s   l o g i s t i c   r e g r e s s i o n   w i t h   b i n a r y   c l a s s i f i c a t i o n   o n l y . 
 
 -   * * D e c i s i o n   T r e e : * *   A   f l e x i b l e   d e c i s i o n   t r e e   i m p l e m e n t a t i o n   f o r   C l a s s i f i c a t i o n   o n l y . 
 
 -   * * R a n d o m   F o r e s t : * *   A n   e n s e m b l e   m e t h o d   u s i n g   m u l t i p l e   d e c i s i o n   t r e e s   f o r   i m p r o v e d   a c c u r a c y . 
 
 -   * * S u p p o r t   V e c t o r   M a c h i n e   ( S V M ) : * *   I n c l u d e s   b o t h   l i n e a r   a n d   k e r n e l - b a s e d   S V M s   w i t h   s u p p o r t   f o r   s o f t   m a r g i n s . 
 
 -   * * k - N e a r e s t   N e i g h b o r s   ( k - N N ) : * *   A   s i m p l e   a n d   i n t u i t i v e   c l a s s i f i c a t i o n   a l g o r i t h m . 
 
 -   * * N a i v e   B a y e s : * *   S u p p o r t s   f o r   G a u s s i a n   N a i v e   B a y e s   f o r   c o n t i n u o u s   D a t a . 
 
 -   * * K M e a n s   C l u s t e r i n g : * *   A   c l u s t e r i n g   a l g o r i t h m . 
 
 -   * * D B S C A N : * *   A   d e n s i t y - b a s e d   c l u s t e r i n g   a l g o r i t h m   f o r   d i s c o v e r i n g   c l u s t e r s   o f   a r b i t r a r y   s h a p e . 
 
 -   * * P C A : * *   D i m e n s i o n a l i t y   R e d u c t i o n   M o d e l   t o   r e d u c e   d i m e n s i o n s   o f   d a t a s e t . 
 
 
 
 # #   I n s t a l l a t i o n 
 
 
 
 Y o u   c a n   i n s t a l l   t h e   p a c k a g e   u s i n g   ` p i p ` : 
 
 
 
 ` ` ` b a s h 
 
 p i p   i n s t a l l   m l t r a i n 
 
 ` ` ` 
 
 
 
 # #   U s a g e 
 
 # #   S u p e r v i s e d   L e a r n i n g   M o d e l s 
 
 # # #   L i n e a r   R e g r e s s i o n 
 
 I t   i s   B u i l t   f r o m   s c r a t c h .   I t   c a n   b e   a p p l i e d   t o   M u l t i p l e   W e i g h t s . . . 
 
 ` ` ` p y t h o n 
 
 f r o m   m l t r a i n . s u p e r v i s e d . L i n e a r R e g r e s s i o n   i m p o r t   L i n e a r R e g r e s s i o n 
 
 
 
 #   I n i t i a l i z e   t h e   m o d e l 
 
 m o d e l   =   L i n e a r R e g r e s s i o n ( l e a r n i n g _ r a t e = 0 . 0 1 ,   e p o c h s = 1 0 0 0 ) 
 
 
 
 #   T r a i n   t h e   m o d e l 
 
 m o d e l . t r a i n ( X _ t r a i n ,   y _ t r a i n ) 
 
 
 
 #   M a k e   p r e d i c t i o n s 
 
 p r e d i c t i o n s   =   m o d e l . p r e d i c t ( X _ t e s t ) 
 
 
 
 ` ` ` 
 
 # # #   L o g i s t i c   R e g r e s s i o n 
 
 I m p l e m e n t e d   o n l y   B i n a r y   C l a s s i f i c a t i o n . 
 
 ` ` ` p y t h o n 
 
 f r o m   m l t r a i n . s u p e r v i s e d . L o g i s t i c R e g r e s s i o n   i m p o r t   L o g i s t i c R e g r e s s i o n 
 
 
 
 #   I n i t i a l i z e   t h e   m o d e l 
 
 m o d e l   =   L o g i s t i c R e g r e s s i o n ( l e a r n i n g _ r a t e = 0 . 0 1 ,   e p o c h s = 1 0 0 0 ) 
 
 
 
 #   T r a i n   t h e   m o d e l 
 
 m o d e l . t r a i n ( X _ t r a i n ,   y _ t r a i n ) 
 
 
 
 #   M a k e   p r e d i c t i o n s 
 
 p r e d i c t i o n s   =   m o d e l . p r e d i c t ( X _ t e s t ) 
 
 
 
 ` ` ` 
 
 # # #   K N N   M o d e l 
 
 Y o u   c a n   u s e   f o r   b o t h   R e g r e s s i o n   a n d   C l a s s i f i c a t i o n .   D e f a u l t   i s   g i v e n   b e l o w : - 
 
 ` ` ` p y t h o n 
 
 f r o m   m l t r a i n . s u p e r v i s e d . K N N   i m p o r t   K N N 
 
 
 
 #   I n i t i a l i z e   t h e   m o d e l 
 
 m o d e l   =   K N N ( k = 3 , d i s t a n c e = ' e u c l i d e a n ' , p u r p o s e = ' c l a s s i f i c a t i o n ' ) 
 
 
 
 #   T r a i n   t h e   m o d e l 
 
 m o d e l . t r a i n ( X _ t r a i n ,   y _ t r a i n ) 
 
 
 
 #   M a k e   p r e d i c t i o n s 
 
 p r e d i c t i o n s   =   m o d e l . p r e d i c t ( X _ t e s t ) 
 
 
 
 ` ` ` 
 
 
 
 # # #   N a i v e   B a y e s   M o d e l 
 
 I m p l e m e n t e d   o n l y   G a u s s i a n   N a i v e   B a y e s . 
 
 ` ` ` p y t h o n 
 
 f r o m   m l t r a i n . s u p e r v i s e d . N a i v e B a y e s   i m p o r t   N a i v e B a y e s 
 
 
 
 #   I n i t i a l i z e   t h e   m o d e l 
 
 m o d e l   =   N a i v e B a y e s ( ) 
 
 
 
 #   T r a i n   t h e   m o d e l 
 
 m o d e l . t r a i n ( X _ t r a i n ,   y _ t r a i n ) 
 
 
 
 #   M a k e   p r e d i c t i o n s 
 
 p r e d i c t i o n s   =   m o d e l . p r e d i c t ( X _ t e s t ) 
 
 
 
 ` ` ` 
 
 
 
 # # #   N a i v e   B a y e s   M o d e l 
 
 I m p l e m e n t e d   o n l y   G a u s s i a n   N a i v e   B a y e s . 
 
 ` ` ` p y t h o n 
 
 f r o m   m l t r a i n . s u p e r v i s e d . N a i v e B a y e s   i m p o r t   N a i v e B a y e s 
 
 
 
 #   I n i t i a l i z e   t h e   m o d e l 
 
 m o d e l   =   N a i v e B a y e s ( ) 
 
 
 
 #   T r a i n   t h e   m o d e l 
 
 m o d e l . t r a i n ( X _ t r a i n ,   y _ t r a i n ) 
 
 
 
 #   M a k e   p r e d i c t i o n s 
 
 p r e d i c t i o n s   =   m o d e l . p r e d i c t ( X _ t e s t ) 
 
 
 
 ` ` ` 
 
 # # #   D e c i s i o n   T r e e 
 
 I m p l e m e n t e d   o n l y   f o r   C l a s s i f i c a t i o n   P u r p o s e   o n l y .   D e f a u l t   P a r a m s   a r e   s h o w n   b e l o w : -   
 
 ` ` ` p y t h o n 
 
 f r o m   m l t r a i n . s u p e r v i s e d . D e c i s i o n T r e e   i m p o r t   D e c i s i o n T r e e 
 
 
 
 #   I n i t i a l i z e   t h e   m o d e l 
 
 m o d e l   =   D e c i s i o n T r e e ( m a x _ d e p t h = 1 0 ,   m i n _ s a m p l e s _ s p l i t = 2 ,   c r i t e r i a = ' g i n i ' ) 
 
 
 
 #   T r a i n   t h e   m o d e l 
 
 m o d e l . t r a i n ( X _ t r a i n ,   y _ t r a i n ) 
 
 
 
 #   M a k e   p r e d i c t i o n s 
 
 p r e d i c t i o n s   =   m o d e l . p r e d i c t ( X _ t e s t ) 
 
 
 
 ` ` ` 
 
 # # #   R a n d o m   F o r e s t 
 
 I m p l e m e n t e d   o n l y   f o r   C l a s s i f i c a t i o n   P u r p o s e   o n l y .   D e f a u l t   P a r a m s   a r e   s h o w n   b e l o w : -   
 
 ` ` ` p y t h o n 
 
 f r o m   m l t r a i n . s u p e r v i s e d . R a n d o m F o r e s t   i m p o r t   R a n d o m F o r e s t 
 
 
 
 #   I n i t i a l i z e   t h e   m o d e l 
 
 m o d e l   =   R a n d o m F o r e s t ( n _ t r e e s = 1 0 0 ,   m a x _ d e p t h = 1 0 ,   m i n _ s a m p l e s _ s p l i t = 2 ,   c r i t e r i a = ' g i n i ' ) 
 
 
 
 #   T r a i n   t h e   m o d e l 
 
 m o d e l . t r a i n ( X _ t r a i n ,   y _ t r a i n ) 
 
 
 
 #   M a k e   p r e d i c t i o n s 
 
 p r e d i c t i o n s   =   m o d e l . p r e d i c t ( X _ t e s t ) 
 
 
 
 ` ` ` 
 
 # # #   K e r n e l S V M   M o d e l 
 
 I m p l e m e n t e d   o n l y   f o r   C l a s s i f i c a t i o n   P u r p o s e   o n l y .   D e f a u l t   P a r a m s   a r e   s h o w n   b e l o w : -   
 
 ` ` ` p y t h o n 
 
 f r o m   m l t r a i n . s u p e r v i s e d . K e r n e l S V M   i m p o r t   K e r n e l S V M 
 
 
 
 #   I n i t i a l i z e   t h e   m o d e l 
 
 m o d e l   =   K e r n e l S V M ( C = 1 . 0 ,   k e r n e l _ t y p e = ' r b f ' ,   e p o c h s = 1 0 0 0 ,   l e a r n i n g _ r a t e = 0 . 0 1 ,   g a m m a = 0 . 5 ,   c o e f 0 = 0 ,   d e g r e e = 3 ) 
 
 
 
 #   T r a i n   t h e   m o d e l 
 
 m o d e l . t r a i n ( X _ t r a i n ,   y _ t r a i n ) 
 
 
 
 #   M a k e   p r e d i c t i o n s 
 
 p r e d i c t i o n s   =   m o d e l . p r e d i c t ( X _ t e s t ) 
 
 
 
 ` ` ` 
 
 # #   U n s u p e r v i s e d   L e a r n i n g   M o d e l s 
 
 # # #   K - M e a n s   C l u s t e r i n g   M o d e l 
 
 ` ` ` p y t h o n 
 
 f r o m   m l t r a i n . u n s u p e r v i s e d . K M e a n s   i m p o r t   K M e a n s 
 
 
 
 #   I n i t i a l i z e   t h e   m o d e l 
 
 m o d e l   =   K M e a n s ( k = 3 ,   e p o c h s = 1 0 0 ) 
 
 
 
 #   T r a i n   t h e   m o d e l   w h i c h   R e t u r n s   C l u s t e r   L a b e l s 
 
 c l u s t e r _ l a b e l s   =   m o d e l . t r a i n ( X _ t r a i n ,   y _ t r a i n ) 
 
 p r i n t ( c l u s t e r _ l a b e l s ) 
 
 
 
 ` ` ` 
 
 # # #   D B S C A N   C l u s t e r i n g   M o d e l 
 
 ` ` ` p y t h o n 
 
 f r o m   m l t r a i n . u n s u p e r v i s e d . D B S C A N   i m p o r t   D B S C A N 
 
 
 
 #   I n i t i a l i z e   t h e   m o d e l 
 
 m o d e l   =   D B S C A N ( e p s i l o n = 0 . 5 ,   m i n _ p o i n t s = 5 ) 
 
 
 
 #   T r a i n   t h e   m o d e l   w h i c h   R e t u r n s   C l u s t e r   L a b e l s 
 
 c l u s t e r _ l a b e l s   =   m o d e l . t r a i n ( X _ t r a i n ,   y _ t r a i n ) 
 
 p r i n t ( c l u s t e r _ l a b e l s ) 
 
 
 
 ` ` ` 
 
 
 
 # # #   P C A 
 
 ` ` ` p y t h o n 
 
 f r o m   m l t r a i n . u n s u p e r v i s e d . P C A   i m p o r t   P C A 
 
 
 
 #   I n i t i l i a z e   t h e   M o d e l 
 
 p c a   =   P C A ( n _ c o m p o n e n t s = 2 ) 
 
 
 
 #   F i t   t h e   D a t a   a n d   p l o t   G r a p h 
 
 X _ p c a   =   p c a . t r a i n _ t r a n s f o r m ( X , p l o t _ g r a p h = T r u e ) 
 
 
 
 #   P r i n t i n g   P C   v a l u e s 
 
 p r i n t ( X _ p c a ) 
 
 
 
 ` ` ` 
 
 # #   C o n t r i b u t i n g 
 
 
 
 P u l l   r e q u e s t s   a r e   w e l c o m e .   F o r   m a j o r   c h a n g e s ,   p l e a s e   o p e n   a n   i s s u e   f i r s t 
 
 t o   d i s c u s s   w h a t   y o u   w o u l d   l i k e   t o   c h a n g e . 
 
 
 
 P l e a s e   m a k e   s u r e   t o   u p d a t e   t e s t s   a s   a p p r o p r i a t e . 
 
 
 
 # #   L i c e n s e 
 
 
 
 [ M I T   L i c e n s e ] ( L I C E N S E ) 
 
 
 
 
 
 
